##############################################
Molecular Dynamics Analysis tool for MLTSA
##############################################

This package called "MD_DATA" has all functions related with the analysis of Molecular Dynamics trajectories prior to
applying MLTSA on MD data. It includes CV selection, CV calculation for dataset generation and binary label
classification similar to IN/OUT in ligand unbinding by manually defining the relevant distances for labeling.
Everything is implemented using the mdtraj package, it can read the same topology files and trajectory files as mdtraj.


.. automodule:: CV_from_MD
   :members:

